package ro.ucv.market;

import java.util.*;

/**
 *  Implement an shopping cart.
 *
 *@created  02 aprilie 2006
 */
public class ShoppingCart {
		/**
		 *  The items list.
		 */
		private List items;


		/**
		 *  The <code>ShoppingCart</code> constructor.
		 */
		public ShoppingCart() {
				items = new ArrayList();
		}


		/**
		 *  Get total price of items from shopping cart.
		 *
		 *@return  The total price.
		 */
		public double getTotal() {
				Iterator i = items.iterator();
				double total = 0.00;
				while (i.hasNext()) {
						Book book = (Book) i.next();
						total = total + book.getPrice();
				}
				return total;
		}


		/**
		 *  Add an item to shopping cart.
		 *
		 *@param  book The book to be added.
		 */
		public void addItem(Book book) {
				items.add(book);
		}


		/**
		 *  Remove an item from shopping cart.
		 *
		 *@param  book The book to be removed.
		 *@throws  Exception If book not found to shopping cart.
		 */
		public void removeItem(Book book) throws Exception {
				if (!items.remove(book)) {
						throw new Exception("Book not found.");
				}
		}


		/**
		 *  Get items count from shopping cart.
		 *
		 *@return  The item count.
		 */
		public int getItemCount() {
				return items.size();
		}


		/**
		 *  Empty shopping cart.
		 */
		public void empty() {
				items.clear();
		}


		/**
		 *  Check if shopping cart is empty.
		 *
		 *@return  <code>true</code> if cart is empty; <code>false</code> otherwhise.
		 */
		public boolean isEmpty() {
				return (items.size() == 0);
		}
}
