package ro.ucv.market;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 *  Clasa <code>ShoppingCartTest</code> este un exemplu de clasa <code>TestCase</code>.
 *
 *@created  04 aprilie 2005
 */
public class ShoppingCartTest extends TestCase {
		/**
		 *  Obiect de tipul ShoppingCart ce va fi testat.
		 */
		private ShoppingCart bookCart;
		/**
		 *  Obiect de tipul Book ce va fi testat.
		 */
		private Book book;


		/**
		 *  Constructor pentru o instanta <code>ShoppingCartTest</code> cu numele
		 *  specificat.
		 *
		 *@param  name Nume test.
		 */
		public ShoppingCartTest(String name) {
				super(name);
		}


		/**
		 *  Initializare obiecte de test. Se apeleaza inaintea fiecarei metode de
		 *  test.
		 */
		protected void setUp() {
				bookCart = new ShoppingCart();
				book = new Book("Unit testing", "John Smith", 35.95);
				bookCart.addItem(book);
		}


		/**
		 *  Distruge obiectele testate. Se apeleaza dupa fiecare metoda de test.
		 */
		protected void tearDown() {
				bookCart = null;
		}


		/**
		 *  Testare inserare carti in cos.
		 */
		public void testBookAdd() {
				Book book = new Book("Extreme machines", "Thomas Manner", 46.95);
				bookCart.addItem(book);
				double expectedTotalPrice = this.book.getPrice() + book.getPrice();
				assertEquals(expectedTotalPrice, bookCart.getTotal(), 0.0);
				assertEquals(2, bookCart.getItemCount());
		}


		/**
		 *  Test golire cos.
		 */
		public void testEmpty() {
				bookCart.empty();
				assertTrue(bookCart.isEmpty());
		}


		/**
		 *  Testare scoatere carti din cos.
		 *
		 *@throws  Exception Daca nu exista acea carte in cos.
		 */
		public void testBookRemove() throws Exception {
				bookCart.removeItem(book);
				assertEquals(0, bookCart.getItemCount());
				assertEquals(0.0, bookCart.getTotal(), 0.0);
		}


		/**
		 *  Testare scoatere carte inexistenta din cos.
		 */
		public void testBookNotFound() {
				try {
						Book book = new Book("Toy story", "John Scott", 54.95);
						bookCart.removeItem(book);
						fail("Trebuie sa semnaleze o exceptie");
				} catch (Exception w) {
				}
		}


		/**
		 *  Asambleaza si returneaza o suita de teste pentru toate metodele de test
		 *  din calasa de test
		 *
		 *@return  O clasa <code>Test</code> nenula.
		 */
		public static Test suite() {
//
// Adaugarea tuturor metodelor de forma testXXX()
// la suita folosind Java Reflection
//
      TestSuite suite = new TestSuite(ShoppingCartTest.class);
//
// Alternativ, se poate adauga cate o metoda de test...
//
// TestSuite suite = new TestSuite();
// suite.addTest(new ShoppingCartTest("testBookAdd"));
// suite.addTest(new ShoppingCartTest("testEmpty"));
// suite.addTest(new ShoppingCartTest("testBookRemove"));
// suite.addTest(new ShoppingCartTest("testBookNotFound"));
//
				return suite;
		}


		/**
		 *  The Main method.
		 *
		 *@param  args Argumentele din linia de comanda.
		 */
		public static void main(String args[]) {
				junit.textui.TestRunner.run(suite());
				junit.swingui.TestRunner.run(ShoppingCartTest.class);
		}
}
